@@ -8,19 +8,19 @@
 
 #include "access/transam.h"
 
+
 static void get_db_infos(migratorContext *ctx, DbInfoArr *dbinfos,
 			 Cluster whichCluster);
 static void dbarr_print(migratorContext *ctx, DbInfoArr *arr,
 			Cluster whichCluster);
 static void relarr_print(migratorContext *ctx, RelInfoArr *arr);
 static void get_rel_infos(migratorContext *ctx, const char *db_name,
-		  RelInfoArr *relarr, Cluster whichCluster);
+			  RelInfoArr *relarr, Cluster whichCluster);
 static void relarr_free(RelInfoArr *rel_arr);
-
 static void map_rel(migratorContext *ctx, const RelInfo *oldrel,
-		const RelInfo *newrel, const DbInfo *old_db,
-		const DbInfo *new_db, const char *olddata,
-		const char *newdata, FileNameMap *map);
+			const RelInfo *newrel, const DbInfo *old_db,
+			const DbInfo *new_db, const char *olddata,
+			const char *newdata, FileNameMap *map);
 static void map_rel_by_id(migratorContext *ctx, Oid oldid, Oid newid,
 			  const char *old_nspname, const char *old_relname,
 			  const char *new_nspname, const char *new_relname,
@@ -28,43 +28,7 @@ static void map_rel_by_id(migratorContext *ctx, Oid oldid, Oid newid,
 			  const DbInfo *new_db, const char *olddata,
 			  const char *newdata, FileNameMap *map);
 static RelInfo *relarr_lookup_reloid(migratorContext *ctx,
-						RelInfoArr *rel_arr, Oid oid,
-						Cluster whichCluster);
-
-
-/*
- *	check_new_db_is_empty
- */
-void
-check_new_db_is_empty(migratorContext *ctx)
-{
-	int			dbnum;
-	bool		found = false;
-	
-	get_db_and_rel_infos(ctx, &ctx->new.dbarr, CLUSTER_NEW);
-
-	for (dbnum = 0; dbnum < ctx->new.dbarr.ndbs; dbnum++)
-	{
-		int			relnum;
-		RelInfoArr	*rel_arr = &ctx->new.dbarr.dbs[dbnum].rel_arr;
-		
-		for (relnum = 0; relnum < rel_arr->nrels;
-			 relnum++)
-		{
-			/* pg_largeobject and its index should be skipped */
-			if (strcmp(rel_arr->rels[relnum].nspname, "pg_catalog") != 0)
-			{
-				found = true;
-				break;
-			}
-		}
-	}
-
-	dbarr_free(&ctx->new.dbarr);
-
-	if (found)
-		pg_log(ctx, PG_FATAL, "New cluster is not empty; exiting\n");
-}
+			 RelInfoArr *rel_arr, Oid oid, Cluster whichCluster);
 
 
 /*
@@ -78,26 +42,26 @@ check_new_db_is_empty(migratorContext *ctx)
  */
 FileNameMap *
 gen_db_file_maps(migratorContext *ctx, DbInfo *old_db, DbInfo *new_db,
-				int *nmaps, const char *old_pgdata, const char *new_pgdata)
+				 int *nmaps, const char *old_pgdata, const char *new_pgdata)
 {
 	FileNameMap *maps;
 	int			relnum;
 	int			num_maps = 0;
 
 	maps = (FileNameMap *) pg_malloc(ctx, sizeof(FileNameMap) *
-						  new_db->rel_arr.nrels);
+									 new_db->rel_arr.nrels);
 
 	for (relnum = 0; relnum < new_db->rel_arr.nrels; relnum++)
 	{
-		RelInfo	   *newrel = &new_db->rel_arr.rels[relnum];
+		RelInfo    *newrel = &new_db->rel_arr.rels[relnum];
 		RelInfo    *oldrel;
-		
+
 		/* toast tables are handled by their parent */
 		if (strcmp(newrel->nspname, "pg_toast") == 0)
 			continue;
 
 		oldrel = relarr_lookup_rel(ctx, &(old_db->rel_arr), newrel->nspname,
-									newrel->relname, CLUSTER_OLD);
+								   newrel->relname, CLUSTER_OLD);
 
 		map_rel(ctx, oldrel, newrel, old_db, new_db, old_pgdata, new_pgdata,
 				maps + num_maps);
@@ -122,9 +86,9 @@ gen_db_file_maps(migratorContext *ctx, DbInfo *old_db, DbInfo *new_db,
 
 			/* look them up in their respective arrays */
 			old_toast = relarr_lookup_reloid(ctx, &old_db->rel_arr,
-								oldrel->toastrelid, CLUSTER_OLD);
+											 oldrel->toastrelid, CLUSTER_OLD);
 			new_toast = relarr_lookup_rel(ctx, &new_db->rel_arr,
-								"pg_toast", new_name, CLUSTER_NEW);
+										  "pg_toast", new_name, CLUSTER_NEW);
 
 			/* finally create a mapping for them */
 			map_rel(ctx, old_toast, new_toast, old_db, new_db, old_pgdata, new_pgdata,
@@ -148,13 +112,13 @@ gen_db_file_maps(migratorContext *ctx, DbInfo *old_db, DbInfo *new_db,
 
 			/* look them up in their respective arrays */
 			old_toast = relarr_lookup_rel(ctx, &old_db->rel_arr,
-								"pg_toast", old_name, CLUSTER_OLD);
+										  "pg_toast", old_name, CLUSTER_OLD);
 			new_toast = relarr_lookup_rel(ctx, &new_db->rel_arr,
-								"pg_toast", new_name, CLUSTER_NEW);
+										  "pg_toast", new_name, CLUSTER_NEW);
 
 			/* finally create a mapping for them */
 			map_rel(ctx, old_toast, new_toast, old_db, new_db, old_pgdata,
-				new_pgdata, maps + num_maps);
+					new_pgdata, maps + num_maps);
 			num_maps++;
 		}
 	}
@@ -164,6 +128,17 @@ gen_db_file_maps(migratorContext *ctx, DbInfo *old_db, DbInfo *new_db,
 }
 
 
+static void
+map_rel(migratorContext *ctx, const RelInfo *oldrel, const RelInfo *newrel,
+		const DbInfo *old_db, const DbInfo *new_db, const char *olddata,
+		const char *newdata, FileNameMap *map)
+{
+	map_rel_by_id(ctx, oldrel->relfilenode, newrel->relfilenode, oldrel->nspname,
+				  oldrel->relname, newrel->nspname, newrel->relname, oldrel->tablespace, old_db,
+				  new_db, olddata, newdata, map);
+}
+
+
 /*
  * map_rel_by_id()
  *
@@ -171,11 +146,11 @@ gen_db_file_maps(migratorContext *ctx, DbInfo *old_db, DbInfo *new_db,
  */
 static void
 map_rel_by_id(migratorContext *ctx, Oid oldid, Oid newid,
-				const char *old_nspname, const char *old_relname,
-				const char *new_nspname, const char *new_relname,
-				const char *old_tablespace, const DbInfo *old_db,
-			  	const DbInfo *new_db, const char *olddata,
-				const char *newdata, FileNameMap *map)
+			  const char *old_nspname, const char *old_relname,
+			  const char *new_nspname, const char *new_relname,
+			  const char *old_tablespace, const DbInfo *old_db,
+			  const DbInfo *new_db, const char *olddata,
+			  const char *newdata, FileNameMap *map)
 {
 	map->new = newid;
 	map->old = oldid;
@@ -188,8 +163,8 @@ map_rel_by_id(migratorContext *ctx, Oid oldid, Oid newid,
 	if (strlen(old_tablespace) == 0)
 	{
 		/*
-		 * relation belongs to the default tablespace, hence relfiles
-		 * would exist in the data directories.
+		 * relation belongs to the default tablespace, hence relfiles would
+		 * exist in the data directories.
 		 */
 		snprintf(map->old_file, sizeof(map->old_file), "%s/base/%u", olddata, old_db->db_oid);
 		snprintf(map->new_file, sizeof(map->new_file), "%s/base/%u", newdata, new_db->db_oid);
@@ -201,31 +176,13 @@ map_rel_by_id(migratorContext *ctx, Oid oldid, Oid newid,
 		 * location
 		 */
 		snprintf(map->old_file, sizeof(map->old_file), "%s%s/%u", old_tablespace,
-				ctx->old.tablespace_suffix, old_db->db_oid);
+				 ctx->old.tablespace_suffix, old_db->db_oid);
 		snprintf(map->new_file, sizeof(map->new_file), "%s%s/%u", old_tablespace,
 				 ctx->new.tablespace_suffix, new_db->db_oid);
 	}
 }
 
 
-/*
- * map_rel()
- *
- * a wrapper over map_rel_by_id().
- */
-static void
-map_rel(migratorContext *ctx, const RelInfo *oldrel, const RelInfo *newrel,
-		const DbInfo *old_db, const DbInfo *new_db, const char *olddata,
-		const char *newdata, FileNameMap *map)
-{
-	map_rel_by_id(ctx, oldrel->relfilenode, newrel->relfilenode, oldrel->nspname,
-		oldrel->relname, newrel->nspname, newrel->relname, oldrel->tablespace, old_db,
-		new_db, olddata, newdata, map);
-}
-
-/*
- *	print_maps
- */
 void
 print_maps(migratorContext *ctx, FileNameMap *maps, int n, const char *dbName)
 {
@@ -237,8 +194,8 @@ print_maps(migratorContext *ctx, FileNameMap *maps, int n, const char *dbName)
 
 		for (mapnum = 0; mapnum < n; mapnum++)
 			pg_log(ctx, PG_DEBUG, "%s.%s:%u ==> %s.%s:%u\n",
-					maps[mapnum].old_nspname, maps[mapnum].old_relname, maps[mapnum].old,
-					maps[mapnum].new_nspname, maps[mapnum].new_relname, maps[mapnum].new);
+				   maps[mapnum].old_nspname, maps[mapnum].old_relname, maps[mapnum].old,
+				   maps[mapnum].new_nspname, maps[mapnum].new_relname, maps[mapnum].new);
 
 		pg_log(ctx, PG_DEBUG, "\n\n");
 	}
@@ -251,7 +208,7 @@ print_maps(migratorContext *ctx, FileNameMap *maps, int n, const char *dbName)
  * Scans pg_database system catalog and returns (in dbinfs_arr) all user
  * databases.
  */
-void
+static void
 get_db_infos(migratorContext *ctx, DbInfoArr *dbinfs_arr, Cluster whichCluster)
 {
 	PGconn	   *conn = connectToServer(ctx, "template1", whichCluster);
@@ -301,7 +258,7 @@ get_db_and_rel_infos(migratorContext *ctx, DbInfoArr *db_arr, Cluster whichClust
 
 	for (dbnum = 0; dbnum < db_arr->ndbs; dbnum++)
 		get_rel_infos(ctx, db_arr->dbs[dbnum].db_name,
-						&(db_arr->dbs[dbnum].rel_arr), whichCluster);
+					  &(db_arr->dbs[dbnum].rel_arr), whichCluster);
 
 	if (ctx->debug)
 		dbarr_print(ctx, db_arr, whichCluster);
@@ -323,7 +280,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 {
 	PGconn	   *conn = connectToServer(ctx, db_name, whichCluster);
 	bool		is_edb_as = (whichCluster == CLUSTER_OLD) ?
-					ctx->old.is_edb_as : ctx->new.is_edb_as;
+	ctx->old.is_edb_as : ctx->new.is_edb_as;
 	PGresult   *res;
 	RelInfo    *relinfos;
 	int			ntups;
@@ -337,77 +294,76 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 	int			i_oid = -1;
 	int			i_relfilenode = -1;
 	int			i_reltoastrelid = -1;
-	char	    query[QUERY_ALLOC];
+	char		query[QUERY_ALLOC];
 
 	/*
-	 *	pg_largeobject contains user data that does not appear
-	 *	the pg_dumpall --schema-only output, so we have to migrate
-	 *	that system table heap and index.  Ideally we could just get the
-	 *  relfilenode from template1 but pg_largeobject_loid_pn_index's
-	 *	relfilenode can change if the table was reindexed so we
-	 *	get the relfilenode for each database and migrate it
-	 *	as a normal user table.
+	 * pg_largeobject contains user data that does not appear the pg_dumpall
+	 * --schema-only output, so we have to migrate that system table heap and
+	 * index.  Ideally we could just get the relfilenode from template1 but
+	 * pg_largeobject_loid_pn_index's relfilenode can change if the table was
+	 * reindexed so we get the relfilenode for each database and migrate it as
+	 * a normal user table.
 	 */
-	 
+
 	snprintf(query, sizeof(query),
-				"SELECT DISTINCT c.oid, n.nspname, c.relname, "
-				"	c.relfilenode, c.reltoastrelid, "
-				"	t.spclocation "
-				"FROM pg_catalog.pg_class c JOIN "
-				"		pg_catalog.pg_namespace n "
-				"	ON c.relnamespace = n.oid "
-				"   LEFT OUTER JOIN pg_catalog.pg_tablespace t "
-				"	ON c.reltablespace = t.oid "
-				"WHERE (( n.nspname NOT IN ('pg_catalog', 'information_schema') "
-				"	AND c.oid >= %u "
-				"	) OR ( "
-				"	n.nspname = 'pg_catalog' "
-				"	AND (relname = 'pg_largeobject' OR "
-				"		 relname = 'pg_largeobject_loid_pn_index') )) "
-				"	AND "
-				"	(relkind = 'r' OR relkind = 't' OR "
-				"	 relkind = 'i'%s)%s"
-				"GROUP BY  c.oid, n.nspname, c.relname, c.relfilenode,"
-				"			c.reltoastrelid, t.spclocation, "
-				"			n.nspname "
-				"ORDER BY n.nspname, c.relname;",
-				FirstNormalObjectId,
-				/* see the comment at the top of v8_3_create_sequence_script() */
-				(GET_MAJOR_VERSION(ctx->old.major_version) <= 803 &&
-				 GET_MAJOR_VERSION(ctx->new.major_version) >= 804) ?
-					"" : " OR relkind = 'S'",
-				/*
-				 *	EDB AS installs pgagent by default via initdb.
-				 *	We have to ignore it, and not migrate any old
-				 *	table contents.
-				 */
-				(is_edb_as && strcmp(db_name, "edb") == 0) ?
-				" 	AND "
-				"	n.nspname != 'pgagent' AND "
-				/* skip pgagent TOAST tables */
-				"	c.oid NOT IN "
-				"	( "
-				"		SELECT c2.reltoastrelid "
-                "		FROM pg_catalog.pg_class c2 JOIN "
-                "				pg_catalog.pg_namespace n2 "
-                "			ON c2.relnamespace = n2.oid "
-				"		WHERE n2.nspname = 'pgagent' AND "
-				"			  c2.reltoastrelid != 0 "
-				"	) AND "
-				/* skip pgagent TOAST table indexes */
-				"	c.oid NOT IN "
-				"	( "
-				"		SELECT c3.reltoastidxid "
-                "		FROM pg_catalog.pg_class c2 JOIN "
-                "				pg_catalog.pg_namespace n2 "
-                "			ON c2.relnamespace = n2.oid JOIN "
-                "				pg_catalog.pg_class c3 "
-				"			ON c2.reltoastrelid = c3.oid "
-				"		WHERE n2.nspname = 'pgagent' AND "
-				"			  c2.reltoastrelid != 0 AND "
-				"			  c3.reltoastidxid != 0 "
-				"	) " : "");
-		
+			 "SELECT DISTINCT c.oid, n.nspname, c.relname, "
+			 "	c.relfilenode, c.reltoastrelid, "
+			 "	t.spclocation "
+			 "FROM pg_catalog.pg_class c JOIN "
+			 "		pg_catalog.pg_namespace n "
+			 "	ON c.relnamespace = n.oid "
+			 "   LEFT OUTER JOIN pg_catalog.pg_tablespace t "
+			 "	ON c.reltablespace = t.oid "
+			 "WHERE (( n.nspname NOT IN ('pg_catalog', 'information_schema') "
+			 "	AND c.oid >= %u "
+			 "	) OR ( "
+			 "	n.nspname = 'pg_catalog' "
+			 "	AND (relname = 'pg_largeobject' OR "
+			 "		 relname = 'pg_largeobject_loid_pn_index') )) "
+			 "	AND "
+			 "	(relkind = 'r' OR relkind = 't' OR "
+			 "	 relkind = 'i'%s)%s"
+			 "GROUP BY  c.oid, n.nspname, c.relname, c.relfilenode,"
+			 "			c.reltoastrelid, t.spclocation, "
+			 "			n.nspname "
+			 "ORDER BY n.nspname, c.relname;",
+			 FirstNormalObjectId,
+	/* see the comment at the top of v8_3_create_sequence_script() */
+			 (GET_MAJOR_VERSION(ctx->old.major_version) <= 803 &&
+			  GET_MAJOR_VERSION(ctx->new.major_version) >= 804) ?
+			 "" : " OR relkind = 'S'",
+
+	/*
+	 * EDB AS installs pgagent by default via initdb. We have to ignore it,
+	 * and not migrate any old table contents.
+	 */
+			 (is_edb_as && strcmp(db_name, "edb") == 0) ?
+			 " 	AND "
+			 "	n.nspname != 'pgagent' AND "
+	/* skip pgagent TOAST tables */
+			 "	c.oid NOT IN "
+			 "	( "
+			 "		SELECT c2.reltoastrelid "
+			 "		FROM pg_catalog.pg_class c2 JOIN "
+			 "				pg_catalog.pg_namespace n2 "
+			 "			ON c2.relnamespace = n2.oid "
+			 "		WHERE n2.nspname = 'pgagent' AND "
+			 "			  c2.reltoastrelid != 0 "
+			 "	) AND "
+	/* skip pgagent TOAST table indexes */
+			 "	c.oid NOT IN "
+			 "	( "
+			 "		SELECT c3.reltoastidxid "
+			 "		FROM pg_catalog.pg_class c2 JOIN "
+			 "				pg_catalog.pg_namespace n2 "
+			 "			ON c2.relnamespace = n2.oid JOIN "
+			 "				pg_catalog.pg_class c3 "
+			 "			ON c2.reltoastrelid = c3.oid "
+			 "		WHERE n2.nspname = 'pgagent' AND "
+			 "			  c2.reltoastrelid != 0 AND "
+			 "			  c3.reltoastidxid != 0 "
+			 "	) " : "");
+
 	res = executeQueryOrDie(ctx, conn, query);
 
 	ntups = PQntuples(res);
@@ -425,7 +381,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 	{
 		RelInfo    *curr;
 		char	   *from = NULL;
-		
+
 		nspname = PQgetvalue(res, relnum, i_nspname);
 		relname = PQgetvalue(res, relnum, i_relname);
 
@@ -453,161 +409,10 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 }
 
 
-/*
- * get_loadable_libraries()
- *
- *	Fetch the names of all old libraries containing C-language functions.
- *	We will later check that they all exist in the new installation.
- */
-void
-get_loadable_libraries(migratorContext *ctx)
-{
-	ClusterInfo	*active_cluster = &ctx->old;
-	PGresult   **ress;
-	int			totaltups;
-	int			dbnum;
-
-	ress = (PGresult **)
-		pg_malloc(ctx, active_cluster->dbarr.ndbs * sizeof(PGresult *));
-	totaltups = 0;
-
-	/* Fetch all library names, removing duplicates within each DB */
-	for (dbnum = 0; dbnum < active_cluster->dbarr.ndbs; dbnum++)
-	{
-		DbInfo	   *active_db = &active_cluster->dbarr.dbs[dbnum];
-		PGconn	   *conn = connectToServer(ctx, active_db->db_name, CLUSTER_OLD);
-
-		/* Fetch all libraries referenced in this DB */
-		ress[dbnum] = executeQueryOrDie(ctx, conn,
-										"SELECT DISTINCT probin "
-										"FROM	pg_catalog.pg_proc "
-										"WHERE	prolang = 13 /* C */ AND "
-										"		probin IS NOT NULL AND "
-										"		oid >= %u;",
-										FirstNormalObjectId);
-		totaltups += PQntuples(ress[dbnum]);
-
-		PQfinish(conn);
-	}
-
-	/* Allocate what's certainly enough space */
-	if (totaltups > 0)
-		ctx->libraries = (char **) pg_malloc(ctx, totaltups * sizeof(char *));
-	else
-		ctx->libraries = NULL;
-
-	/*
-	 * Now remove duplicates across DBs.  This is pretty inefficient code,
-	 * but there probably aren't enough entries to matter.
-	 */
-	totaltups = 0;
-
-	for (dbnum = 0; dbnum < active_cluster->dbarr.ndbs; dbnum++)
-	{
-		PGresult   *res = ress[dbnum];
-		int			ntups;
-		int			rowno;
-
-		ntups = PQntuples(res);
-		for (rowno = 0; rowno < ntups; rowno++)
-		{
-			char   *lib = PQgetvalue(res, rowno, 0);
-			bool	dup = false;
-			int		n;
-
-			for (n = 0; n < totaltups; n++)
-			{
-				if (strcmp(lib, ctx->libraries[n]) == 0)
-				{
-					dup = true;
-					break;
-				}
-			}
-			if (!dup)
-				ctx->libraries[totaltups++] = pg_strdup(ctx, lib);
-		}
-
-		PQclear(res);
-	}
-
-	ctx->num_libraries = totaltups;
-
-	pg_free(ress);
-}
-
-
-/*
- * check_loadable_libraries()
- *
- *	Check that the new cluster contains all required libraries.
- *	We do this by actually trying to LOAD each one, thereby testing
- *	compatibility as well as presence.
- */
-void
-check_loadable_libraries(migratorContext *ctx)
-{
-	PGconn	   *conn = connectToServer(ctx, "template1", CLUSTER_NEW);
-	int			libnum;
-	FILE		*script = NULL;
-	bool		found = false;
-	char		output_path[MAXPGPATH];
-
-	prep_status(ctx, "Checking for presence of required libraries");
-
-	snprintf(output_path, sizeof(output_path), "%s/loadable_libraries.txt",
-			ctx->output_dir);
-	
-	for (libnum = 0; libnum < ctx->num_libraries; libnum++)
-	{
-		char	   *lib = ctx->libraries[libnum];
-		int			llen = strlen(lib);
-		char	   *cmd = (char *) pg_malloc(ctx, 8 + 2 * llen + 1);
-		PGresult   *res;
-
-		strcpy(cmd, "LOAD '");
-		PQescapeStringConn(conn, cmd + 6, lib, llen, NULL);
-		strcat(cmd, "'");
-
-		res = PQexec(conn, cmd);
-
-		if (PQresultStatus(res) != PGRES_COMMAND_OK)
-		{
-			found = true;
-			if (script == NULL && (script = fopen(output_path, "w")) == NULL)
-				pg_log(ctx, PG_FATAL, "Could not create necessary file:  %s\n",
-					   output_path);
-			fprintf(script, "Failed to load library: %s\n%s\n",
-					lib,
-					PQerrorMessage(conn));
-		}
-
-		PQclear(res);
-		pg_free(cmd);
-	}
-
-	PQfinish(conn);
-
-	if (found)
-	{
-		fclose(script);
-		pg_log(ctx, PG_REPORT, "fatal\n");
-		pg_log(ctx, PG_FATAL,
-				"| Your installation uses loadable libraries that are missing\n"
-				"| from the new installation.  You can add these libraries to\n"
-				"| the new installation, or remove the functions using them\n"
-				"| from the old installation.  A list of the problem libraries\n"
-				"| is in the file\n"
-				"| \"%s\".\n\n", output_path);
-	}
-	else
-		check_ok(ctx);
-}
-
-
 /*
  * dbarr_lookup_db()
  *
- * NOTE: returns the *real* pointer to the DbInfo structure
+ * Returns the pointer to the DbInfo structure
  */
 DbInfo *
 dbarr_lookup_db(DbInfoArr *db_arr, const char *db_name)
@@ -630,13 +435,13 @@ dbarr_lookup_db(DbInfoArr *db_arr, const char *db_name)
 /*
  * relarr_lookup_rel()
  *
- * searches "relname" in rel_arr. Returns the *real* pointer to the
- * RelInfo structure
+ * Searches "relname" in rel_arr. Returns the *real* pointer to the
+ * RelInfo structure.
  */
 RelInfo *
 relarr_lookup_rel(migratorContext *ctx, RelInfoArr *rel_arr,
-					const char *nspname, const char *relname,
-					Cluster whichCluster)
+				  const char *nspname, const char *relname,
+				  Cluster whichCluster)
 {
 	int			relnum;
 
@@ -650,7 +455,7 @@ relarr_lookup_rel(migratorContext *ctx, RelInfoArr *rel_arr,
 			return &rel_arr->rels[relnum];
 	}
 	pg_log(ctx, PG_FATAL, "Could not find %s.%s in %s cluster\n",
-		nspname, relname, CLUSTERNAME(whichCluster));
+		   nspname, relname, CLUSTERNAME(whichCluster));
 	return NULL;
 }
 
@@ -658,7 +463,7 @@ relarr_lookup_rel(migratorContext *ctx, RelInfoArr *rel_arr,
 /*
  * relarr_lookup_reloid()
  *
- *	returns a pointer to the RelInfo structure for the
+ *	Returns a pointer to the RelInfo structure for the
  *	given oid or NULL if the desired entry cannot be
  *	found.
  */
@@ -677,14 +482,11 @@ relarr_lookup_reloid(migratorContext *ctx, RelInfoArr *rel_arr, Oid oid,
 			return &rel_arr->rels[relnum];
 	}
 	pg_log(ctx, PG_FATAL, "Could not find %d in %s cluster\n",
-		oid, CLUSTERNAME(whichCluster));
+		   oid, CLUSTERNAME(whichCluster));
 	return NULL;
 }
 
 
-/*
- * relarr_free()
- */
 static void
 relarr_free(RelInfoArr *rel_arr)
 {
@@ -693,9 +495,6 @@ relarr_free(RelInfoArr *rel_arr)
 }
 
 
-/*
- * dbarr_free()
- */
 void
 dbarr_free(DbInfoArr *db_arr)
 {
@@ -707,24 +506,6 @@ dbarr_free(DbInfoArr *db_arr)
 }
 
 
-/*
- *	relarr_print
- */
-static void
-relarr_print(migratorContext *ctx, RelInfoArr *arr)
-{
-	int			relnum;
-
-	for (relnum = 0; relnum < arr->nrels; relnum++)
-		pg_log(ctx, PG_DEBUG, "relname: %s.%s: reloid: %u reltblspace: %s\n",
-				arr->rels[relnum].nspname, arr->rels[relnum].relname,
-				arr->rels[relnum].reloid, arr->rels[relnum].tablespace);
-}
-
-
-/*
- *	dbarr_print
- */
 static void
 dbarr_print(migratorContext *ctx, DbInfoArr *arr, Cluster whichCluster)
 {
@@ -739,3 +520,15 @@ dbarr_print(migratorContext *ctx, DbInfoArr *arr, Cluster whichCluster)
 		pg_log(ctx, PG_DEBUG, "\n\n");
 	}
 }
+
+
+static void
+relarr_print(migratorContext *ctx, RelInfoArr *arr)
+{
+	int			relnum;
+
+	for (relnum = 0; relnum < arr->nrels; relnum++)
+		pg_log(ctx, PG_DEBUG, "relname: %s.%s: reloid: %u reltblspace: %s\n",
+			   arr->rels[relnum].nspname, arr->rels[relnum].relname,
+			   arr->rels[relnum].reloid, arr->rels[relnum].tablespace);
+}
