@@ -12,6 +12,7 @@
 #include <io.h>
 #endif
 
+
 static void usage(migratorContext *ctx);
 static void validateDirectoryOption(migratorContext *ctx, char **dirpath,
 				   char *envVarName, char *cmdLineOption, char *description);
@@ -45,9 +46,10 @@ parseCommandLine(migratorContext *ctx, int argc, char *argv[])
 		{"verbose", no_argument, NULL, 'v'},
 		{NULL, 0, NULL, 0}
 	};
-	char option;				/* Command line option */
+	char		option;			/* Command line option */
 	int			optindex = 0;	/* used by getopt_long */
 	char		user_name[USER_NAME_SIZE];
+
 #ifdef WIN32
 	DWORD		bufsize = USER_NAME_SIZE - 1;
 
@@ -83,9 +85,9 @@ parseCommandLine(migratorContext *ctx, int argc, char *argv[])
 	get_home_path(ctx->home_dir);
 #else
 	{
-		char 		*tmppath;
+		char	   *tmppath;
 
-		 /* TMP is the best place on Windows, rather than APPDATA */
+		/* TMP is the best place on Windows, rather than APPDATA */
 		if ((tmppath = getenv("TMP")) == NULL)
 			pg_log(ctx, PG_FATAL, "TMP environment variable is not set.\n");
 		snprintf(ctx->home_dir, MAXPGPATH, "%s", tmppath);
@@ -93,9 +95,9 @@ parseCommandLine(migratorContext *ctx, int argc, char *argv[])
 #endif
 
 	snprintf(ctx->output_dir, MAXPGPATH, "%s/" OUTPUT_SUBDIR, ctx->home_dir);
-	
+
 	while ((option = getopt_long(argc, argv, "d:D:b:B:cgG:kl:p:P:u:v",
-								 long_options, &optindex)) !=-1)
+								 long_options, &optindex)) != -1)
 	{
 		switch (option)
 		{
@@ -177,9 +179,9 @@ parseCommandLine(migratorContext *ctx, int argc, char *argv[])
 	if (ctx->logfile != NULL)
 	{
 		/*
-		 *	We must use append mode so output generated by child processes
-		 *	via ">>" will not be overwritten, and we want the file
-		 *	truncated on start.
+		 * We must use append mode so output generated by child processes via
+		 * ">>" will not be overwritten, and we want the file truncated on
+		 * start.
 		 */
 		/* truncate */
 		ctx->log_fd = fopen(ctx->logfile, "w");
@@ -215,9 +217,6 @@ parseCommandLine(migratorContext *ctx, int argc, char *argv[])
 }
 
 
-/*
- *	usage
- */
 static void
 usage(migratorContext *ctx)
 {
@@ -302,8 +301,8 @@ validateDirectoryOption(migratorContext *ctx, char **dirpath,
 		else
 		{
 			pg_log(ctx, PG_FATAL, "You must identify the directory where the %s\n"
-						  "Please use the %s command-line option or the %s environment variable\n",
-						  description, cmdLineOption, envVarName);
+				   "Please use the %s command-line option or the %s environment variable\n",
+				   description, cmdLineOption, envVarName);
 		}
 	}
 
@@ -316,12 +315,6 @@ validateDirectoryOption(migratorContext *ctx, char **dirpath,
 }
 
 
-/*
- * get_pkglibdirs()
- *
- * gets pkglibdir for the oldbindir and newbindir
- * and retains them in migratorContext
- */
 static void
 get_pkglibdirs(migratorContext *ctx)
 {
@@ -330,11 +323,6 @@ get_pkglibdirs(migratorContext *ctx)
 }
 
 
-/*
- * get_pkglibdir()
- *
- * gets pkglibdir by invoking pg_config --pkglibdir for the given bindir
- */
 static char *
 get_pkglibdir(migratorContext *ctx, const char *bindir)
 {
@@ -347,7 +335,7 @@ get_pkglibdir(migratorContext *ctx, const char *bindir)
 
 	if ((output = popen(cmd, "r")) == NULL)
 		pg_log(ctx, PG_FATAL, "Could not get pkglibdir data: %s\n",
-			   strerror(errno));
+			   getErrorText(errno));
 
 	fgets(bufin, sizeof(bufin), output);
 
